==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/SUPPLIERCOMMODITYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour SUPPLIERCOMMODITYID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="SUPPLIERCOMMODITYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COMMODITYID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SUPPLIERCOMMODITYID_Type", propOrder = {
    "supplierid",
    "commodityid"
})
public class SUPPLIERCOMMODITYID_Type {

    @XmlElement(name = "SUPPLIERID", required = true)
    protected SUPPLIERID_Type supplierid;
    @XmlElement(name = "COMMODITYID", required = true)
    protected COMMODITY_Type commodityid;

    /**
     * Obtient la valeur de la propriété supplierid.
     * 
     * @return
     *     possible object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public SUPPLIERID_Type getSUPPLIERID() {
        return supplierid;
    }

    /**
     * Définit la valeur de la propriété supplierid.
     * 
     * @param value
     *     allowed object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public void setSUPPLIERID(SUPPLIERID_Type value) {
        this.supplierid = value;
    }

    /**
     * Obtient la valeur de la propriété commodityid.
     * 
     * @return
     *     possible object is
     *     {@link COMMODITY_Type }
     *     
     */
    public COMMODITY_Type getCOMMODITYID() {
        return commodityid;
    }

    /**
     * Définit la valeur de la propriété commodityid.
     * 
     * @param value
     *     allowed object is
     *     {@link COMMODITY_Type }
     *     
     */
    public void setCOMMODITYID(COMMODITY_Type value) {
        this.commodityid = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/SUPPLIERCOMMODITYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SUPPLIERCOMMODITYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SUPPLIERCOMMODITYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COMMODITYID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SUPPLIERCOMMODITYID_Type", propOrder = {
    "supplierid",
    "commodityid"
})
public class SUPPLIERCOMMODITYID_Type {

    @XmlElement(name = "SUPPLIERID", required = true)
    protected SUPPLIERID_Type supplierid;
    @XmlElement(name = "COMMODITYID", required = true)
    protected COMMODITY_Type commodityid;

    /**
     * Gets the value of the supplierid property.
     * 
     * @return
     *     possible object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public SUPPLIERID_Type getSUPPLIERID() {
        return supplierid;
    }

    /**
     * Sets the value of the supplierid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public void setSUPPLIERID(SUPPLIERID_Type value) {
        this.supplierid = value;
    }

    /**
     * Gets the value of the commodityid property.
     * 
     * @return
     *     possible object is
     *     {@link COMMODITY_Type }
     *     
     */
    public COMMODITY_Type getCOMMODITYID() {
        return commodityid;
    }

    /**
     * Sets the value of the commodityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link COMMODITY_Type }
     *     
     */
    public void setCOMMODITYID(COMMODITY_Type value) {
        this.commodityid = value;
    }

}
